import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { DeviceVO, DeviceForm, DeviceQuery } from '@/api/qms/device/types';

/**
 * 查询测试仪列表
 * @param query
 * @returns {*}
 */

export const listDevice = (query?: DeviceQuery): AxiosPromise<DeviceVO[]> => {
  return request({
    url: '/qms/device/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询测试仪详细
 * @param id
 */
export const getDevice = (id: string | number): AxiosPromise<DeviceVO> => {
  return request({
    url: '/qms/device/' + id,
    method: 'get'
  });
};

/**
 * 新增测试仪
 * @param data
 */
export const addDevice = (data: DeviceForm) => {
  return request({
    url: '/qms/device',
    method: 'post',
    data: data
  });
};

/**
 * 修改测试仪
 * @param data
 */
export const updateDevice = (data: DeviceForm) => {
  return request({
    url: '/qms/device',
    method: 'put',
    data: data
  });
};

/**
 * 删除测试仪
 * @param id
 */
export const delDevice = (id: string | number | Array<string | number>) => {
  return request({
    url: '/qms/device/' + id,
    method: 'delete'
  });
};
